==> aws-java-sdk-gamelift-1.10.56-sources.jar: com/amazonaws/services/gamelift/model/transform/GameSessionJsonUnmarshaller.java <==
/*
 * Copyright 2010-2016 Amazon.com, Inc. or its affiliates. All Rights
 * Reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License").
 * You may not use this file except in compliance with the License.
 * A copy of the License is located at
 *
 *  http://aws.amazon.com/apache2.0
 *
 * or in the "license" file accompanying this file. This file is distributed
 * on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either
 * express or implied. See the License for the specific language governing
 * permissions and limitations under the License.
 */

package com.amazonaws.services.gamelift.model.transform;

import java.util.Map;
import java.util.Map.Entry;

import com.amazonaws.services.gamelift.model.*;
import com.amazonaws.transform.SimpleTypeJsonUnmarshallers.*;
import com.amazonaws.transform.*;

import com.fasterxml.jackson.core.JsonToken;
import static com.fasterxml.jackson.core.JsonToken.*;

/**
 * GameSession JSON Unmarshaller
 */
public class GameSessionJsonUnmarshaller implements
        Unmarshaller<GameSession, JsonUnmarshallerContext> {

    public GameSession unmarshall(JsonUnmarshallerContext context)
            throws Exception {
        GameSession gameSession = new GameSession();

        int originalDepth = context.getCurrentDepth();
        String currentParentElement = context.getCurrentParentElement();
        int targetDepth = originalDepth + 1;

        JsonToken token = context.getCurrentToken();
        if (token == null)
            token = context.nextToken();
        if (token == VALUE_NULL)
            return null;

        while (true) {
            if (token == null)
                break;

            if (token == FIELD_NAME || token == START_OBJECT) {
                if (context.testExpression("GameSessionId", targetDepth)) {
                    context.nextToken();
                    gameSession.setGameSessionId(StringJsonUnmarshaller
                            .getInstance().unmarshall(context));
                }
                if (context.testExpression("Name", targetDepth)) {
                    context.nextToken();
                    gameSession.setName(StringJsonUnmarshaller.getInstance()
                            .unmarshall(context));
                }
                if (context.testExpression("FleetId", targetDepth)) {
                    context.nextToken();
                    gameSession.setFleetId(StringJsonUnmarshaller.getInstance()
                            .unmarshall(context));
                }
                if (context.testExpression("CreationTime", targetDepth)) {
                    context.nextToken();
                    gameSession.setCreationTime(DateJsonUnmarshaller
                            .getInstance().unmarshall(context));
                }
                if (context.testExpression("TerminationTime", targetDepth)) {
                    context.nextToken();
                    gameSession.setTerminationTime(DateJsonUnmarshaller
                            .getInstance().unmarshall(context));
                }
                if (context.testExpression("CurrentPlayerSessionCount",
                        targetDepth)) {
                    context.nextToken();
                    gameSession
                            .setCurrentPlayerSessionCount(IntegerJsonUnmarshaller
                                    .getInstance().unmarshall(context));
                }
                if (context.testExpression("MaximumPlayerSessionCount",
                        targetDepth)) {
                    context.nextToken();
                    gameSession
                            .setMaximumPlayerSessionCount(IntegerJsonUnmarshaller
                                    .getInstance().unmarshall(context));
                }
                if (context.testExpression("Status", targetDepth)) {
                    context.nextToken();
                    gameSession.setStatus(StringJsonUnmarshaller.getInstance()
                            .unmarshall(context));
                }
                if (context.testExpression("GameProperties", targetDepth)) {
                    context.nextToken();
                    gameSession
                            .setGameProperties(new ListUnmarshaller<GameProperty>(
                                    GamePropertyJsonUnmarshaller.getInstance())
                                    .unmarshall(context));
                }
                if (context.testExpression("IpAddress", targetDepth)) {
                    context.nextToken();
                    gameSession.setIpAddress(StringJsonUnmarshaller
                            .getInstance().unmarshall(context));
                }
                if (context.testExpression("PlayerSessionCreationPolicy",
                        targetDepth)) {
                    context.nextToken();
                    gameSession
                            .setPlayerSessionCreationPolicy(StringJsonUnmarshaller
                                    .getInstance().unmarshall(context));
                }
            } else if (token == END_ARRAY || token == END_OBJECT) {
                if (context.getLastParsedParentElement() == null
                        || context.getLastParsedParentElement().equals(
                                currentParentElement)) {
                    if (context.getCurrentDepth() <= originalDepth)
                        break;
                }
            }
            token = context.nextToken();
        }

        return gameSession;
    }

    private static GameSessionJsonUnmarshaller instance;

    public static GameSessionJsonUnmarshaller getInstance() {
        if (instance == null)
            instance = new GameSessionJsonUnmarshaller();
        return instance;
    }
}

==> aws-java-sdk-gamelift-1.11.30-sources.jar: com/amazonaws/services/gamelift/model/transform/GameSessionJsonUnmarshaller.java <==
/*
 * Copyright 2011-2016 Amazon.com, Inc. or its affiliates. All Rights Reserved.
 * 
 * Licensed under the Apache License, Version 2.0 (the "License"). You may not
 * use this file except in compliance with the License. A copy of the License is
 * located at
 * 
 * http://aws.amazon.com/apache2.0
 * 
 * or in the "license" file accompanying this file. This file is distributed on
 * an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either
 * express or implied. See the License for the specific language governing
 * permissions and limitations under the License.
 */
package com.amazonaws.services.gamelift.model.transform;

import java.util.Map;
import java.util.Map.Entry;
import java.math.*;
import java.nio.ByteBuffer;

import com.amazonaws.services.gamelift.model.*;
import com.amazonaws.transform.SimpleTypeJsonUnmarshallers.*;
import com.amazonaws.transform.*;

import com.fasterxml.jackson.core.JsonToken;
import static com.fasterxml.jackson.core.JsonToken.*;

/**
 * GameSession JSON Unmarshaller
 */
public class GameSessionJsonUnmarshaller implements
        Unmarshaller<GameSession, JsonUnmarshallerContext> {

    public GameSession unmarshall(JsonUnmarshallerContext context)
            throws Exception {
        GameSession gameSession = new GameSession();

        int originalDepth = context.getCurrentDepth();
        String currentParentElement = context.getCurrentParentElement();
        int targetDepth = originalDepth + 1;

        JsonToken token = context.getCurrentToken();
        if (token == null)
            token = context.nextToken();
        if (token == VALUE_NULL)
            return null;

        while (true) {
            if (token == null)
                break;

            if (token == FIELD_NAME || token == START_OBJECT) {
                if (context.testExpression("GameSessionId", targetDepth)) {
                    context.nextToken();
                    gameSession.setGameSessionId(context.getUnmarshaller(
                            String.class).unmarshall(context));
                }
                if (context.testExpression("Name", targetDepth)) {
                    context.nextToken();
                    gameSession.setName(context.getUnmarshaller(String.class)
                            .unmarshall(context));
                }
                if (context.testExpression("FleetId", targetDepth)) {
                    context.nextToken();
                    gameSession.setFleetId(context
                            .getUnmarshaller(String.class).unmarshall(context));
                }
                if (context.testExpression("CreationTime", targetDepth)) {
                    context.nextToken();
                    gameSession.setCreationTime(context.getUnmarshaller(
                            java.util.Date.class).unmarshall(context));
                }
                if (context.testExpression("TerminationTime", targetDepth)) {
                    context.nextToken();
                    gameSession.setTerminationTime(context.getUnmarshaller(
                            java.util.Date.class).unmarshall(context));
                }
                if (context.testExpression("CurrentPlayerSessionCount",
                        targetDepth)) {
                    context.nextToken();
                    gameSession
                            .setCurrentPlayerSessionCount(context
                                    .getUnmarshaller(Integer.class).unmarshall(
                                            context));
                }
                if (context.testExpression("MaximumPlayerSessionCount",
                        targetDepth)) {
                    context.nextToken();
                    gameSession
                            .setMaximumPlayerSessionCount(context
                                    .getUnmarshaller(Integer.class).unmarshall(
                                            context));
                }
                if (context.testExpression("Status", targetDepth)) {
                    context.nextToken();
                    gameSession.setStatus(context.getUnmarshaller(String.class)
                            .unmarshall(context));
                }
                if (context.testExpression("GameProperties", targetDepth)) {
                    context.nextToken();
                    gameSession
                            .setGameProperties(new ListUnmarshaller<GameProperty>(
                                    GamePropertyJsonUnmarshaller.getInstance())
                                    .unmarshall(context));
                }
                if (context.testExpression("IpAddress", targetDepth)) {
                    context.nextToken();
                    gameSession.setIpAddress(context.getUnmarshaller(
                            String.class).unmarshall(context));
                }
                if (context.testExpression("Port", targetDepth)) {
                    context.nextToken();
                    gameSession.setPort(context.getUnmarshaller(Integer.class)
                            .unmarshall(context));
                }
                if (context.testExpression("PlayerSessionCreationPolicy",
                        targetDepth)) {
                    context.nextToken();
                    gameSession.setPlayerSessionCreationPolicy(context
                            .getUnmarshaller(String.class).unmarshall(context));
                }
            } else if (token == END_ARRAY || token == END_OBJECT) {
                if (context.getLastParsedParentElement() == null
                        || context.getLastParsedParentElement().equals(
                                currentParentElement)) {
                    if (context.getCurrentDepth() <= originalDepth)
                        break;
                }
            }
            token = context.nextToken();
        }

        return gameSession;
    }

    private static GameSessionJsonUnmarshaller instance;

    public static GameSessionJsonUnmarshaller getInstance() {
        if (instance == null)
            instance = new GameSessionJsonUnmarshaller();
        return instance;
    }
}
